import { Metadata as RawMetadata } from 'pdfjs-dist/types/display/metadata';
export declare enum VerbosityLevel {
    ERRORS,
    INFOS,
    WARNINGS
}
export declare type PdfDataOptions = {
    password?: string;
    max?: number;
    sort?: boolean;
    verbosity?: VerbosityLevel;
};
export declare type Info = Readonly<{
    Title?: string;
    Author?: string;
    Subject?: string;
    Keywords?: string;
    Creator?: string;
    Producer?: string;
    CreationDate?: string;
    ModDate?: string;
    Trapped?: {
        readonly name: string;
    };
    PDFFormatVersion: string;
    IsLinearized: boolean;
    IsAcroFormPresent: boolean;
    IsXFAPresent: boolean;
    IsCollectionPresent: boolean;
    IsSignaturesPresent: boolean;
    [key: string]: string | number | boolean | {
        readonly name: string;
    } | undefined;
}>;
export declare type PdfOutline = {
    readonly title: string;
    readonly url: string;
    readonly childs?: readonly PdfOutline[];
} | {
    readonly title: string;
    readonly page: number;
    readonly childs?: readonly PdfOutline[];
};
export declare type Metadata = RawMetadata;
export declare type Permissions = {
    readonly assemble: boolean;
    readonly copy: boolean;
    readonly fillInteractiveForms: boolean;
    readonly modifyAnnotations: boolean;
    readonly modifyContents: boolean;
    readonly print: boolean;
    readonly printHQ: boolean;
    readonly copyForAccessibility: boolean;
};
export declare class PdfData {
    readonly pages: number;
    readonly text: readonly string[];
    readonly fingerprint: string;
    readonly outline: readonly PdfOutline[];
    readonly info?: Info;
    readonly metadata?: Metadata;
    readonly permissions?: Permissions;
    private constructor();
    /**
     * Returns the extracted data from a pdf file
     *
     * @param {Uint8Array} data The pdf file in the form of byte data
     * @param {PdfDataOptions} options The options how to read the data
     * @returns {Promise<PdfData>}
     * @memberof PdfData
     */
    static extract(data: Uint8Array, options?: PdfDataOptions): Promise<PdfData>;
}
